urlparam
open | /demo/kss_url_param_multiprop.html |
assertElementPresent | target |
click | button_1 |
waitForTextPresent | Method 1 called |
assertTextPresent | Method 1 called |
click | button_2 |
waitForTextPresent | Method 2 called |
assertTextPresent | Method 2 called |
click | button_3 |
waitForTextPresent | Method 3 called |
assertTextPresent | Method 3 called |
click | button_4 |
waitForTextPresent | Method 3 called |
assertTextPresent | Method 3 called |